@@ -74,6 +74,16 @@ def build_argparser():
         'add one or more glob expressions to show a subset of the registers, like "e?x eip" (x86) or "r*" (arm).'
     )
 
+    parser.add_argument(
+        "-i",
+        "--init",
+        metavar='<file>',
+        dest='init_file',
+        required=False,
+        help=
+        'execute the instructions from the given file before starting the interactive session.'
+    )
+
     parser.add_argument(
         '-V',
         '--version',
