@@ -3,12 +3,18 @@ from .shell import create_shell_session, display_registers, process_command_or_r
 from .cmdline import build_argparser
 
 from keystone import KsError
+from unicorn import UcError
 
 
 def main():
     parser = build_argparser()
     args = parser.parse_args()
 
+    init_inputs = []
+    if args.init_file:
+        with open(args.init_file, 'rt') as f:
+            init_inputs = list(f.readlines())
+
     # Initialize engines
     ks, mu, regs, pc, mem = get_engines(args.arch, args.mode)
 
@@ -27,17 +33,17 @@ def main():
     # map 2MB memory for this emulation
     mem[ADDRESS:ADDRESS + args.code_sz] = 0
 
-    # map 0x2000 bytes (8KB) memory to play with
-    mem[0x2000:0x4000] = 0
-
     # TODO what is the meaning of a loop?
     pc.val = ADDRESS
     pc_addr = ADDRESS
     while True:
         try:
-            display_registers(visible_regs, columns=4)
+            if init_inputs:
+                text = init_inputs.pop(0)
+            else:
+                display_registers(visible_regs, columns=4)
+                text = session.prompt('%s> ' % pc.repr_val())
 
-            text = session.prompt('%s> ' % pc.repr_val())
             code_comment = process_command_or_return_code(text, regs, mem, mu)
             if code_comment is None:
                 continue
@@ -51,11 +57,20 @@ def main():
                 print("Syntax error: %s" % e)
                 continue
 
-            # write machine code to be emulated to memory
-            mu.mem_write(pc_addr, instrs)
+            try:
+                # write machine code to be emulated to memory
+                mu.mem_write(pc_addr, instrs)
+            except UcError as e:
+                print("Memory write error: %s" % e)
+                continue
+
+            try:
+                # emulate code in infinite time & unlimited instructions
+                mu.emu_start(pc_addr, pc_addr + len(instrs))
+            except UcError as e:
+                print("Execution error: %s" % e)
+                continue
 
-            # emulate code in infinite time & unlimited instructions
-            mu.emu_start(pc_addr, pc_addr + len(instrs))
             pc_addr += len(instrs)
 
         except KeyboardInterrupt:
